@@ -427,7 +427,8 @@ describe 'ceph::repo' do
     context 'when using CentOS SIG repository' do
       let :params do
         {
-          :enable_sig => true,
+          :enable_sig  => true,
+          :enable_epel => false,
         }
       end
 
@@ -444,6 +445,7 @@ describe 'ceph::repo' do
       let :params do
         {
           :enable_sig  => true,
+          :enable_epel => false,
           :ceph_mirror => 'https://mymirror/luminous/',
         }
       end
@@ -594,7 +596,7 @@ describe 'ceph::repo' do
       end
 
       it { should contain_yumrepo('ceph-storage-sig').with(
-        :baseurl => 'http://mirror.stream.centos.org/SIGs/9-stream/storage/x86_64/ceph-nautilus/',
+        :baseurl => 'https://mirror.stream.centos.org/SIGs/9-stream/storage/x86_64/ceph-nautilus/',
       )}
     end
   end
