@@ -40,7 +40,7 @@ if ! test -b \$disk ; then
     # Since nautilus, only block devices or lvm logical volumes can be used for OSDs
     exit 1
 fi
-ceph-volume lvm prepare  --cluster ceph  --data vg_test/lv_test 
+ceph-volume lvm prepare --cluster ceph --data vg_test/lv_test
 ",
         'unless'    => "/bin/true # comment to satisfy puppet syntax requirements
 set -ex
@@ -83,27 +83,12 @@ ps -fCceph-osd|grep \"\\--id \$id \"
         {
           :cluster       => 'testcluster',
           :journal       => '/srv/journal',
-          :fsid          => 'f39ace04-f967-4c3d-9fd2-32af2d2d2cd5',
           :store_type    => 'bluestore',
           :bluestore_wal => 'vg_test/lv_wal',
           :bluestore_db  => 'vg_test/lv_db',
         }
       end
 
-      it { should contain_exec('ceph-osd-check-fsid-mismatch-vg_test/lv_test').with(
-        'command'   => "/bin/true # comment to satisfy puppet syntax requirements
-set -ex
-exit 1
-",
-        'unless'    => "/bin/true # comment to satisfy puppet syntax requirements
-set -ex
-if [ -z $(ceph-volume lvm list vg_test/lv_test |grep 'cluster fsid' | awk -F'fsid' '{print \$2}'|tr -d  ' ') ]; then
-    exit 0
-fi
-test f39ace04-f967-4c3d-9fd2-32af2d2d2cd5 = $(ceph-volume lvm list vg_test/lv_test |grep 'cluster fsid' | awk -F'fsid' '{print \$2}'|tr -d  ' ')
-",
-        'logoutput' => true
-      ) }
       it { should contain_exec('ceph-osd-prepare-vg_test/lv_test').with(
         'command'   => "/bin/true # comment to satisfy puppet syntax requirements
 set -ex
@@ -118,7 +103,7 @@ if ! test -b \$disk ; then
     # Since nautilus, only block devices or lvm logical volumes can be used for OSDs
     exit 1
 fi
-ceph-volume lvm prepare --bluestore --cluster testcluster --cluster-fsid f39ace04-f967-4c3d-9fd2-32af2d2d2cd5 --data vg_test/lv_test --block.wal vg_test/lv_wal --block.db vg_test/lv_db
+ceph-volume lvm prepare --bluestore --cluster testcluster --data vg_test/lv_test --block.wal vg_test/lv_wal --block.db vg_test/lv_db
 ",
         'unless'    => "/bin/true # comment to satisfy puppet syntax requirements
 set -ex
@@ -178,7 +163,7 @@ if ! test -b \$disk ; then
     # Since nautilus, only block devices or lvm logical volumes can be used for OSDs
     exit 1
 fi
-ceph-volume lvm prepare  --cluster ceph --dmcrypt --dmcrypt-key-dir '/etc/ceph/dmcrypt-keys'  --data /dev/sdc 
+ceph-volume lvm prepare --cluster ceph --dmcrypt --dmcrypt-key-dir '/etc/ceph/dmcrypt-keys' --data /dev/sdc
 ",
         'unless'    => "/bin/true # comment to satisfy puppet syntax requirements
 set -ex
@@ -239,7 +224,7 @@ if ! test -b \$disk ; then
     # Since nautilus, only block devices or lvm logical volumes can be used for OSDs
     exit 1
 fi
-ceph-volume lvm prepare  --cluster ceph --dmcrypt --dmcrypt-key-dir '/srv/ceph/keys'  --data /dev/sdc 
+ceph-volume lvm prepare --cluster ceph --dmcrypt --dmcrypt-key-dir '/srv/ceph/keys' --data /dev/sdc
 ",
         'unless'    => "/bin/true # comment to satisfy puppet syntax requirements
 set -ex
@@ -369,7 +354,7 @@ if ! test -b \$disk ; then
     # Since nautilus, only block devices or lvm logical volumes can be used for OSDs
     exit 1
 fi
-ceph-volume lvm prepare  --cluster ceph  --data /dev/nvme0n1 
+ceph-volume lvm prepare --cluster ceph --data /dev/nvme0n1
 ",
         'unless'    => "/bin/true # comment to satisfy puppet syntax requirements
 set -ex
@@ -423,7 +408,7 @@ if ! test -b \$disk ; then
     # Since nautilus, only block devices or lvm logical volumes can be used for OSDs
     exit 1
 fi
-ceph-volume lvm prepare  --cluster ceph  --data /dev/cciss/c0d0 
+ceph-volume lvm prepare --cluster ceph --data /dev/cciss/c0d0
 ",
         'unless'    => "/bin/true # comment to satisfy puppet syntax requirements
 set -ex
@@ -511,11 +496,13 @@ fi
         }
       end
 
-      it { should raise_error(Puppet::Error, /Ensure on OSD must be either present or absent/) }
+      it { should raise_error(Puppet::PreformattedError) }
     end
   end
 
-  on_supported_os.each do |os,facts|
+  on_supported_os({
+    :supported_os => OSDefaults.get_supported_os
+  }).each do |os,facts|
     context "on #{os}" do
       let (:facts) do
         facts.merge!(OSDefaults.get_facts())
