@@ -2,22 +2,17 @@
 $LOAD_PATH.push(File.join(File.dirname(__FILE__), 'fixtures', 'modules', 'openstacklib', 'lib'))
 require 'puppetlabs_spec_helper/module_spec_helper'
 require 'shared_examples'
+require 'puppet-openstack_spec_helper/facts'
 
-require 'puppet-openstack_spec_helper/defaults'
-require 'rspec-puppet-facts'
-include RspecPuppetFacts
+fixture_path = File.expand_path(File.join(File.dirname(__FILE__), 'fixtures'))
 
 RSpec.configure do |c|
   c.alias_it_should_behave_like_to :it_configures, 'configures'
   c.alias_it_should_behave_like_to :it_raises, 'raises'
-  # TODO(aschultz): remove this after all tests converted to use OSDefaults
-  # instead of referencing @default_facts
-  c.before :each do
-    @default_facts = OSDefaults.get_facts
-  end
-  fixture_path = File.expand_path(File.join(File.dirname(__FILE__), 'fixtures'))
 
   c.hiera_config = File.join(fixture_path, 'hieradata/hiera.yaml')
+  c.module_path = File.join(fixture_path, 'modules')
+  c.manifest_dir = File.join(fixture_path, 'manifests')
 
   c.before(:all) do
     data = YAML.load_file(c.hiera_config)
